<?php

/***************************************************************************\
 *  SPIP, Systeme de publication pour l'internet                           *
 *                                                                         *
 *  Copyright (c) 2001-2016                                                *
 *  Arnaud Martin, Antoine Pitrou, Philippe Riviere, Emmanuel Saint-James  *
 *                                                                         *
 *  Ce programme est un logiciel libre distribue sous licence GNU/GPL.     *
 *  Pour plus de details voir le fichier COPYING.txt ou l'aide en ligne.   *
\***************************************************************************/

/**
 * Gestion de l'action supprimer_mot
 *
 * @package SPIP\Mots\Actions
 */
if (!defined("_ECRIRE_INC_VERSION")) {
	return;
}

/**
 * Action supprimant un mot clé dans la base de données dont l'identifiant
 * est en argument de l'action sécurisée
 */
function action_supprimer_mot_dist() {

	$securiser_action = charger_fonction('securiser_action', 'inc');
	$id_mot = $securiser_action();

	include_spip('action/editer_mot');
	mot_supprimer($id_mot);
}
